Package: lapop
Type: Package
Title: Processing, Visualizing, and Labeling Americas Barometer Data
Version: 2.1.7
Authors@R: c(person(given = "Robert", family = "Vidigal", 
             role = c("cre","aut"), 
             email = "robert.vidigal@vanderbilt.edu", 
             comment = c(ORCID = "0000-0001-5713-119X")),
             person(given = "Luke", family = "Plutowski", 
             role = c("ctb", "aut"), 
             email = "luke.plutowski@vanderbilt.edu", 
             comment = c(ORCID = "0000-0001-8240-6722")))
Author: Robert Vidigal [cre, aut] (ORCID:
    <https://orcid.org/0000-0001-5713-119X>),
  Luke Plutowski [ctb, aut] (ORCID:
    <https://orcid.org/0000-0001-8240-6722>)
Date: 2026-08-04
Maintainer: Robert Vidigal <robert.vidigal@vanderbilt.edu>
Description: Labeling, weighting, and plotting data following custom style guidelines for use in reports, presentations, and social media posts. The Center for Global Democracy (formerly the Latin American Public Opinion Project) at Vanderbilt University is a leader in public survey research, best known for the Americas Barometer project. The publicly available data can be downloaded from: <https://www.vanderbilt.edu/lapop/data-access.php>.
URL: https://lapop-central.github.io/lapop/
Depends: R (>= 4.1.0)
Imports: ggplot2, ggtext, ggrepel, showtext, grid, gridtext, gridExtra,
        sf, sysfonts, systemfonts, svglite, dplyr, srvyr, survey,
        haven, stats, purrr, tibble, marginaleffects, stringr, zoo
VignetteBuilder: knitr
Suggests: readstata13, rio, rprojroot, knitr, rmarkdown, ggpattern,
        testthat (>= 3.0.0)
Language: en-US
Encoding: UTF-8
License: MIT + file LICENSE
RoxygenNote: 7.3.3
Config/testthat/edition: 3
Collate: 'bra23.R' 'cm23.R' 'globals.R' 'lapop-deprecated.R'
        'lapop_fonts.R' 'lapop_cc.R' 'lapop_cccomb.R' 'lapop_ccm.R'
        'lapop_coef.R' 'lapop_dumb.R' 'lapop_fonts_design.R'
        'lapop_hist.R' 'lapop_map.R' 'lapop_mline.R' 'lapop_mover.R'
        'lapop_save.R' 'lapop_stack.R' 'lapop_ts.R' 'lpr_cc.R'
        'lpr_ccm.R' 'lpr_ci.R' 'lpr_coef.R' 'lpr_data.R' 'lpr_dumb.R'
        'lpr_extract_notes.R' 'lpr_extract_ros.R' 'lpr_hist.R'
        'lpr_mline.R' 'lpr_mover.R' 'lpr_na_attributes.R' 'lpr_resc.R'
        'lpr_set_attr.R' 'lpr_set_ros.R' 'lpr_stack.R' 'lpr_ts.R'
        'world.R' 'ym23.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2026-08-04 16:19:18 UTC; vidigar
Repository: CRAN
Date/Publication: 2026-08-04 17:50:30 UTC
Built: R 4.5.2; ; 2026-08-04 18:41:18 UTC; unix
