# Generated by roxygen2: do not edit by hand

export(bra23)
export(cm23)
export(lapop_cc)
export(lapop_cccomb)
export(lapop_ccm)
export(lapop_coef)
export(lapop_db)
export(lapop_demog)
export(lapop_dumb)
export(lapop_fonts)
export(lapop_fonts_design)
export(lapop_hist)
export(lapop_map)
export(lapop_mline)
export(lapop_mover)
export(lapop_save)
export(lapop_sb)
export(lapop_stack)
export(lapop_ts)
export(lapop_tsmulti)
export(lpr_cc)
export(lpr_ccm)
export(lpr_ci)
export(lpr_coef)
export(lpr_data)
export(lpr_dumb)
export(lpr_extract_notes)
export(lpr_extract_ros)
export(lpr_hist)
export(lpr_mline)
export(lpr_mover)
export(lpr_na_attributes)
export(lpr_resc)
export(lpr_set_attr)
export(lpr_set_ros)
export(lpr_stack)
export(lpr_ts)
export(world)
export(ym23)
import(dplyr)
import(ggplot2)
import(ggtext)
import(grDevices)
import(grid)
import(gridtext)
import(haven)
import(marginaleffects)
import(purrr)
import(showtext)
import(srvyr)
import(stringr)
import(survey)
import(sysfonts)
import(systemfonts)
import(tibble)
importFrom(dplyr,filter)
importFrom(dplyr,left_join)
importFrom(dplyr,rename)
importFrom(ggrepel,geom_text_repel)
importFrom(ggtext,element_markdown)
importFrom(gridExtra,grid.arrange)
importFrom(sf,st_bbox)
importFrom(sf,st_drop_geometry)
importFrom(stats,Gamma)
importFrom(stats,ave)
importFrom(stats,confint)
importFrom(stats,gaussian)
importFrom(stats,na.omit)
importFrom(stats,poisson)
importFrom(stats,quasibinomial)
importFrom(stats,quasipoisson)
importFrom(stats,reorder)
importFrom(stats,setNames)
importFrom(stringr,str_wrap)
importFrom(svglite,svglite)
importFrom(zoo,na.approx)
