utils::globalVariables(
  c("wave", "prop1", "prop2", "prop1_low", "prop1_upp", "pais", "ub1",
    "lb1", "ub2", "lb2", "pt", "write.csv", "complete.cases", "coef",
    "var", "as.formula", "qt", "combn", "xint",

    "Estimate", "Pr(>|t|)", "Std. Error", "conf.high", "conf.low",
    ".", "x_display", ":=", "label_table_names", "alpha_value",

    "geometry",    # sf object
    "value", # renamed user input variable to map

    "contrast", "hl_var", "lb", "note_id", "p.value", "prop",
    "prop2_low", "prop2_upp", "prop_low", "prop_upp", "proplabel",
    "proplabel1", "proplabel2", "pvalue", "strata", "ub", "upm",
    "vallabel", "varlabel", "varterm", "weight1500", "xvar_label",
    "year", "category")
)
