## lapop-deprecated.r
#' @title Deprecated functions in package \pkg{lapop}.
#' @description The functions listed below are deprecated and will be defunct in
#'   the near future. When possible, alternative functions with similar
#'   functionality are also mentioned. Help pages for deprecated functions are
#'   available at \code{help("<function>-deprecated")}.
#' @name lapop-deprecated
#' @keywords internal
#' @return No return value, called for side effects
NULL
