% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lapop_fonts.R
\name{lapop_fonts}
\alias{lapop_fonts}
\title{LAPOP Fonts}
\usage{
lapop_fonts()
}
\value{
No return value, called for side effects
}
\description{
This function loads fonts needed for LAPOP graph formatting.
No arguments needed; just run lapop_fonts() at the beginning of your session.
}
\examples{
\donttest{require(lapop); lapop_fonts()}

}
\author{
Luke Plutowski, \email{luke.plutowski@vanderbilt.edu} & Robert Vidigal, \email{robert.vidigal@vanderbilt.edu}
}
